Package 'popPyramid'

Title: Population Pyramids
Description: Functions that facilitate the elaboration of population pyramids.
Authors: Jorge L. C. Musaja [aut, cre]
Maintainer: Jorge L. C. Musaja <[email protected]>
License: GPL-3
Version: 0.1.1
Built: 2026-05-26 09:45:42 UTC
Source: https://github.com/musajajorge/poppyramid

Help Index


Labels for pyramid plot

Description

Requires the following aesthetics:

  • x

  • y

  • split: The variable on which to stratify the plot

Usage

geom_label_pyramid(
  mapping = NULL,
  data = NULL,
  stat = "identity",
  position = "nudge",
  ...,
  na.rm = FALSE,
  show.legend = NA,
  inherit.aes = TRUE
)

Arguments

mapping

Set of aesthetic mappings created by aes(). If specified and inherit.aes = TRUE (the default), it is combined with the default mapping at the top level of the plot. You must supply mapping if there is no plot mapping.

data

The data to be displayed in this layer. There are three options:

If NULL, the default, the data is inherited from the plot data as specified in the call to ggplot().

A data.frame, or other object, will override the plot data. All objects will be fortified to produce a data frame. See fortify() for which variables will be created.

A function will be called with a single argument, the plot data. The return value must be a data.frame, and will be used as the layer data. A function can be created from a formula (e.g. ~ head(.x, 10)).

stat

The statistical transformation to use on the data for this layer. When using a ⁠geom_*()⁠ function to construct a layer, the stat argument can be used the override the default coupling between geoms and stats. The stat argument accepts the following:

  • A Stat ggproto subclass, for example StatCount.

  • A string naming the stat. To give the stat as a string, strip the function name of the stat_ prefix. For example, to use stat_count(), give the stat as "count".

  • For more information and other ways to specify the stat, see the layer stat documentation.

position

A position adjustment to use on the data for this layer. Cannot be jointy specified with nudge_x or nudge_y. This can be used in various ways, including to prevent overplotting and improving the display. The position argument accepts the following:

  • The result of calling a position function, such as position_jitter().

  • A string nameing the position adjustment. To give the position as a string, strip the function name of the position_ prefix. For example, to use position_jitter(), give the position as "jitter".

  • For more information and other ways to specify the position, see the layer position documentation.

...

Other arguments passed on to layer()'s params argument. These arguments broadly fall into one of 4 categories below. Notably, further arguments to the position argument, or aesthetics that are required can not be passed through .... Unknown arguments that are not part of the 4 categories below are ignored.

  • Static aesthetics that are not mapped to a scale, but are at a fixed value and apply to the layer as a whole. For example, colour = "red" or linewidth = 3. The geom's documentation has an Aesthetics section that lists the available options. The 'required' aesthetics cannot be passed on to the params. Please note that while passing unmapped aesthetics as vectors is technically possible, the order and required length is not guaranteed to be parallel to the input data.

  • When constructing a layer using a ⁠stat_*()⁠ function, the ... argument can be used to pass on parameters to the geom part of the layer. An example of this is stat_density(geom = "area", outline.type = "both"). The geom's documentation lists which parameters it can accept.

  • Inversely, when constructing a layer using a ⁠geom_*()⁠ function, the ... argument can be used to pass on parameters to the stat part of the layer. An example of this is geom_area(stat = "density", adjust = 0.5). The stat's documentation lists which parameters it can accept.

  • The key_glyph argument of layer() may also be passed on through .... This can be one of the functions described as key glyphs, to change the display of the layer in the legend.

na.rm

If FALSE, the default, missing values are removed with a warning. If TRUE, missing values are silently removed.

show.legend

logical. Should this layer be included in the legends? NA, the default, includes if any aesthetics are mapped. FALSE never includes, and TRUE always includes. It can also be a named logical vector to finely select the aesthetics to display.

inherit.aes

If FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g. borders().

Details

Other aesthetics are passed onto 'geom_label'


Back-to-back pyramid plots

Description

A column plot with back-to-back labels, stratified on some input variables.

Usage

geom_pyramid(
  mapping = NULL,
  data = NULL,
  stat = "identity",
  position = "stack",
  ...,
  just = 0.5,
  width = NULL,
  na.rm = FALSE,
  orientation = NA,
  show.legend = NA,
  inherit.aes = TRUE
)

Arguments

mapping

Set of aesthetic mappings created by aes(). If specified and inherit.aes = TRUE (the default), it is combined with the default mapping at the top level of the plot. You must supply mapping if there is no plot mapping.

data

The data to be displayed in this layer. There are three options:

If NULL, the default, the data is inherited from the plot data as specified in the call to ggplot().

A data.frame, or other object, will override the plot data. All objects will be fortified to produce a data frame. See fortify() for which variables will be created.

A function will be called with a single argument, the plot data. The return value must be a data.frame, and will be used as the layer data. A function can be created from a formula (e.g. ~ head(.x, 10)).

stat

The statistical transformation to use on the data for this layer. When using a ⁠geom_*()⁠ function to construct a layer, the stat argument can be used the override the default coupling between geoms and stats. The stat argument accepts the following:

  • A Stat ggproto subclass, for example StatCount.

  • A string naming the stat. To give the stat as a string, strip the function name of the stat_ prefix. For example, to use stat_count(), give the stat as "count".

  • For more information and other ways to specify the stat, see the layer stat documentation.

position

A position adjustment to use on the data for this layer. This can be used in various ways, including to prevent overplotting and improving the display. The position argument accepts the following:

  • The result of calling a position function, such as position_jitter(). This method allows for passing extra arguments to the position.

  • A string naming the position adjustment. To give the position as a string, strip the function name of the position_ prefix. For example, to use position_jitter(), give the position as "jitter".

  • For more information and other ways to specify the position, see the layer position documentation.

...

Other arguments passed on to layer()'s params argument. These arguments broadly fall into one of 4 categories below. Notably, further arguments to the position argument, or aesthetics that are required can not be passed through .... Unknown arguments that are not part of the 4 categories below are ignored.

  • Static aesthetics that are not mapped to a scale, but are at a fixed value and apply to the layer as a whole. For example, colour = "red" or linewidth = 3. The geom's documentation has an Aesthetics section that lists the available options. The 'required' aesthetics cannot be passed on to the params. Please note that while passing unmapped aesthetics as vectors is technically possible, the order and required length is not guaranteed to be parallel to the input data.

  • When constructing a layer using a ⁠stat_*()⁠ function, the ... argument can be used to pass on parameters to the geom part of the layer. An example of this is stat_density(geom = "area", outline.type = "both"). The geom's documentation lists which parameters it can accept.

  • Inversely, when constructing a layer using a ⁠geom_*()⁠ function, the ... argument can be used to pass on parameters to the stat part of the layer. An example of this is geom_area(stat = "density", adjust = 0.5). The stat's documentation lists which parameters it can accept.

  • The key_glyph argument of layer() may also be passed on through .... This can be one of the functions described as key glyphs, to change the display of the layer in the legend.

just

Adjustment for column placement. Set to 0.5 by default, meaning that columns will be centered about axis breaks. Set to 0 or 1 to place columns to the left/right of axis breaks. Note that this argument may have unintended behaviour when used with alternative positions, e.g. position_dodge().

width

Bar width. By default, set to 90% of the resolution() of the data.

na.rm

If FALSE, the default, missing values are removed with a warning. If TRUE, missing values are silently removed.

orientation

The orientation of the layer. The default (NA) automatically determines the orientation from the aesthetic mapping. In the rare event that this fails it can be given explicitly by setting orientation to either "x" or "y". See the Orientation section for more detail.

show.legend

logical. Should this layer be included in the legends? NA, the default, includes if any aesthetics are mapped. FALSE never includes, and TRUE always includes. It can also be a named logical vector to finely select the aesthetics to display.

inherit.aes

If FALSE, overrides the default aesthetics, rather than combining with them. This is most useful for helper functions that define both data and aesthetics and shouldn't inherit behaviour from the default plot specification, e.g. borders().

Details

Requires the following aesthetics:

  • x

  • y

  • split: The variable on which to stratify the plot

Other aesthetics are passed onto 'geom_col'


Label values by absolute value

Description

Label values by absolute value

Usage

labeller_abs(...)

Arguments

...

Extra arguments passed to 'format'

Value

Function that can be used to format values, best used inside 'scale_*' or 'geom_label'-like functions.


Creates percentage of a dataframe

Description

Creates a dataframe in long format and in percent

Usage

percDF(df, age, sex, pop)

Arguments

df

Name of dataframe

age

Age or age group. Write the parameter in quotation marks.

sex

Sex or other categorical grouping variable. Write the parameter in quotation marks.

pop

Population (in numerical value). Write the parameter in quotation marks.

Value

The dataframe in long format and in percentage

Examples

df <- popPyramid::popPER
df <- dplyr::filter(df, Year==2021)
df <- percDF(df, "Age", "Sex", "Population")

Population percentage pyramid graph

Description

Create a population percentage pyramid graph

Usage

plotPercPyramid(
  df,
  age,
  sex,
  perpop,
  labx = perpop,
  laby = age,
  twocolors = c("#41ae76", "#ef6548"),
  rotation = 0,
  n.breaks = 20,
  value.labels = TRUE,
  position.value.labels = "in",
  size.value.labels = 3
)

Arguments

df

Name of dataframe

age

Age or age group. Write the parameter in quotation marks.

sex

Sex or other categorical grouping variable. Write the parameter in quotation marks.

perpop

Percentage of population (in numerical value). Write the parameter in quotation marks.

labx

X-axis label

laby

Y-axis label

twocolors

Two colors for the pyramid

rotation

X-axis label rotation

n.breaks

Number of breaks

value.labels

Show values in the bars. Use TRUE to include the labels in the bars. Use FALSE to not include them.

position.value.labels

Position of the values on the bars. Use "in" to display the labels inside the bars. Use "out" to display them outside the bars.

size.value.labels

Font size of the values in the bars

Value

A graph of the pyramid of population percentage

Examples

df <- popPyramid::popPER
df <- dplyr::filter(df, Year==2021)
df <- percDF(df, "gAge", "Sex", "Population")
plotPercPyramid(df=df, age="gAge", sex="Sex", perpop="perc_Population", value.labels=FALSE)

Population pyramid graph

Description

Create a population pyramid graph

Usage

plotPyramid(
  df,
  age,
  sex,
  pop,
  labx = pop,
  laby = age,
  twocolors = c("#41ae76", "#ef6548"),
  rotation = 90,
  n.breaks = 20,
  value.labels = TRUE,
  position.value.labels = "in",
  size.value.labels = 3
)

Arguments

df

Name of dataframe

age

Age or age group. Write the parameter in quotation marks.

sex

Sex or other categorical grouping variable. Write the parameter in quotation marks.

pop

Population (in numerical value). Write the parameter in quotation marks.

labx

X-axis label

laby

Y-axis label

twocolors

Two colors for the pyramid

rotation

X-axis label rotation

n.breaks

Number of breaks

value.labels

Show values in the bars. Use TRUE to include the labels in the bars. Use FALSE to not include them.

position.value.labels

Position of the values on the bars. Use "in" to display the labels inside the bars. Use "out" to display them outside the bars.

size.value.labels

Font size of the values in the bars

Value

A population pyramid graph

Examples

df <- popPyramid::popPER
df <- dplyr::filter(df, Year==2021)
plotPyramid(df=df, age="gAge", sex="Sex", pop="Population", value.labels=FALSE)

Peru population (1995-2030)

Description

Peru population (1995-2030)

Usage

popPER

Format

dataframe

Year

chr Year

Sex

chr Sex

Age

chr Age

gAge

chr Age group

Population

dbl Population